pub enum SuspendedCommandPoll {
Pending,
Ready(Result<i32, CommandError>),
}Expand description
Poll result for a public command whose result is produced across ticks.
Variants
Pending
The command remains suspended.
Ready(Result<i32, CommandError>)
The command completed with a result or execution error.