pub struct CommandArgument {
inner: SteelArgumentType,
}Expand description
An argument parser accepted by a public command node.
Fields
inner: SteelArgumentTypeImplementations
Sourceimpl CommandArgument
impl CommandArgument
Sourcepub fn integer(minimum: i32, maximum: i32) -> Self
pub fn integer(minimum: i32, maximum: i32) -> Self
Creates a bounded signed 32-bit integer argument.
Sourcepub fn long(minimum: i64, maximum: i64) -> Self
pub fn long(minimum: i64, maximum: i64) -> Self
Creates a bounded signed 64-bit integer argument.
Sourcepub fn float(minimum: f32, maximum: f32) -> Self
pub fn float(minimum: f32, maximum: f32) -> Self
Creates a bounded 32-bit floating-point argument.
Sourcepub fn double(minimum: f64, maximum: f64) -> Self
pub fn double(minimum: f64, maximum: f64) -> Self
Creates a bounded 64-bit floating-point argument.
Sourcepub fn greedy_string() -> Self
pub fn greedy_string() -> Self
Creates an argument that consumes the remaining command input.
Sourcepub fn custom<P>(parser: P) -> Selfwhere
P: CommandArgumentParser,
pub fn custom<P>(parser: P) -> Selfwhere
P: CommandArgumentParser,
Erases a keyed extension parser without using Any or TypeId.
fn primitive(argument: ArgumentType) -> Self