pub struct CommandContext<'context> {
inner: &'context CommandContext<CommandSource, SteelCommandRuntime>,
}Expand description
A parsed command invocation exposed to an extension executor.
Fields
inner: &'context CommandContext<CommandSource, SteelCommandRuntime>Implementations
Sourceimpl<'context> CommandContext<'context>
impl<'context> CommandContext<'context>
Sourcepub fn source(self) -> CommandSource<'context>
pub fn source(self) -> CommandSource<'context>
Returns the execution source.
Sourcepub fn value<T: DowncastType>(self, name: &str) -> Option<&'context T>
pub fn value<T: DowncastType>(self, name: &str) -> Option<&'context T>
Returns a parsed custom value by its deterministic concrete type key.
Sourcepub fn boolean(self, name: &str) -> Option<bool>
pub fn boolean(self, name: &str) -> Option<bool>
Returns a parsed boolean, or None when the named argument has another type.
Sourcepub fn string(self, name: &str) -> Option<&'context str>
pub fn string(self, name: &str) -> Option<&'context str>
Returns a parsed word, phrase, or greedy string.
Sourcepub fn domain(self, name: &str) -> Option<&'context str>
pub fn domain(self, name: &str) -> Option<&'context str>
Returns a parsed configured domain name.
Sourcepub fn world(self, name: &str) -> Result<Arc<World>, CommandError>
pub fn world(self, name: &str) -> Result<Arc<World>, CommandError>
Resolves a parsed loaded-world argument against the current source domain.
Sourcepub fn players(self, name: &str) -> Result<Vec<Arc<Player>>, CommandError>
pub fn players(self, name: &str) -> Result<Vec<Arc<Player>>, CommandError>
Resolves a player selector and requires at least one result.
Sourcepub fn player(self, name: &str) -> Result<Arc<Player>, CommandError>
pub fn player(self, name: &str) -> Result<Arc<Player>, CommandError>
Resolves a single player selector.
Sourcepub fn entities(self, name: &str) -> Result<Vec<SharedEntity>, CommandError>
pub fn entities(self, name: &str) -> Result<Vec<SharedEntity>, CommandError>
Resolves an entity selector and requires at least one result.
Sourcepub fn entity(self, name: &str) -> Result<SharedEntity, CommandError>
pub fn entity(self, name: &str) -> Result<SharedEntity, CommandError>
Resolves a single entity selector.