CommandNode

Struct CommandNode 

pub struct CommandNode {
    inner: CommandNodeBuilder<CommandSource, SteelCommandRuntime>,
}
One literal or argument node in a server command declaration.

Fields

inner: CommandNodeBuilder<CommandSource, SteelCommandRuntime>

Implementations

Source

impl CommandNode

pub fn literal(name: impl Into<Box<str>>) -> Self

Creates a literal node.

pub fn argument(name: impl Into<Box<str>>, argument: CommandArgument) -> Self

Creates a typed argument node.

pub fn then(self, child: Self) -> Self

Adds a child while preserving declaration order.

pub fn executes( self, executor: impl for<'context> Fn(&CommandContext<'context>) -> Result<i32, CommandError> + Send + Sync + 'static, ) -> Self

Attaches a synchronous terminal executor.

pub fn executes_suspended<T>( self, executor: impl for<'context> Fn(&CommandContext<'context>) -> Result<T, CommandError> + Send + Sync + 'static, ) -> Self

Attaches a terminal executor whose result is produced across server ticks.

pub fn requires( self, requirement: impl for<'source> Fn(CommandSource<'source>) -> bool + Send + Sync + 'static, ) -> Self

Adds a non-permission source requirement used for tree visibility and execution.