pub struct CommandParserSource<'source> {
inner: &'source dyn CommandArgumentSource,
}Expand description
Read-only source facts available while a custom argument is parsed.
Fields
inner: &'source dyn CommandArgumentSourceImplementations
Sourceimpl CommandParserSource<'_>
impl CommandParserSource<'_>
Sourcepub fn domain_names(&self) -> Vec<&str>
pub fn domain_names(&self) -> Vec<&str>
Returns configured domain names.
Sourcepub fn world_names(&self) -> Vec<String>
pub fn world_names(&self) -> Vec<String>
Returns world names visible to the current command source.
Sourcepub fn player_names(&self) -> Vec<String>
pub fn player_names(&self) -> Vec<String>
Returns player names visible to selectors in the source domain.
Sourcepub fn permission_group_names(&self) -> Vec<String>
pub fn permission_group_names(&self) -> Vec<String>
Returns configured permission group names.