pub struct CommandNode {
inner: CommandNodeBuilder<CommandSource, SteelCommandRuntime>,
}Expand description
One literal or argument node in a server command declaration.
Fields
inner: CommandNodeBuilder<CommandSource, SteelCommandRuntime>Implementations
Sourceimpl CommandNode
impl CommandNode
Sourcepub fn argument(name: impl Into<Box<str>>, argument: CommandArgument) -> Self
pub fn argument(name: impl Into<Box<str>>, argument: CommandArgument) -> Self
Creates a typed argument node.
Sourcepub fn executes(
self,
executor: impl for<'context> Fn(&CommandContext<'context>) -> Result<i32, CommandError> + Send + Sync + 'static,
) -> Self
pub fn executes( self, executor: impl for<'context> Fn(&CommandContext<'context>) -> Result<i32, CommandError> + Send + Sync + 'static, ) -> Self
Attaches a synchronous terminal executor.
Sourcepub fn executes_suspended<T>(
self,
executor: impl for<'context> Fn(&CommandContext<'context>) -> Result<T, CommandError> + Send + Sync + 'static,
) -> Selfwhere
T: SuspendedCommand,
pub fn executes_suspended<T>(
self,
executor: impl for<'context> Fn(&CommandContext<'context>) -> Result<T, CommandError> + Send + Sync + 'static,
) -> Selfwhere
T: SuspendedCommand,
Attaches a terminal executor whose result is produced across server ticks.